@@ -1,15 +1,14 @@
 from Naked.toolshed.shell import (muterun_js, execute_js)
 import sys, base64, json, os
 from eosjs_python.Exceptions import * 
-import eosjs_python.js
 
 class Eos:
-
 	current_dir = os.path.dirname(os.path.realpath(__file__))
+
 	def __init__(self, config):
 		self.http_address = config['http_address'] if 'http_address' in config else 'http://127.0.0.1:8888'
-		self.key_provider = config['key_provider'] if 'keyProvider' in config else '5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3'
-		print('current dir', self.current_dir)
+		self.key_provider = config['key_provider'] if 'key_provider' in config else '5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3'
+
 	@classmethod
 	def generate_key_pair(cls):
 		response = muterun_js(cls.current_dir + '/js/GenerateKeys.js')
@@ -36,12 +35,50 @@ class Eos:
 			config['delegatebw_stake_cpu_quantity'] if 'delegatebw_stake_cpu_quantity' in config else '100.0000 SYS',
 			config['delegatebw_transfer'] if 'delegatebw_transfer' in config else 0
 		)
-		response = muterun_js(self.current_dir + '/js/GenerateKeys.js', arguments=arguments)
+		response = muterun_js(self.current_dir + '/js/CreateAccount.js', arguments=arguments)
 		if response.exitcode == 0:
 			print(response.stdout.decode('utf8'))
 		else:
 		    raise CreateAccountException(response.stderr)
-	
+
+	def push_transaction(self, acct_contract, func_name, acct_owner, permission, data):
+		"""
+		node PushContractTransaction.js 'http://127.0.0.1:8888' '5JhhMGNPsuU52XXjZ57FcDKvbb7KLrEhN65tdTQFrH51uruZLHi' 'eosio.token' 'transfer' 'eva' 'active' '{"from":"eva","to":"rider1","quantity":"1 EVA","memo":""}'
+		"""
+		arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' " % (
+			self.http_address,
+			self.key_provider,
+			acct_contract,
+			func_name,
+			acct_owner,
+			permission,
+			json.dumps(data)
+		)
+		response = muterun_js(self.current_dir + '/js/PushContractTransaction.js', arguments=arguments)
+		if response.exitcode == 0:
+			print(response.stdout.decode('utf8'))
+		else:
+		    raise PushContractTransactionException(response.stderr)
+
+	def get_table(self, code, scope, table):
+		"""
+		node GetTable.js 'http://127.0.0.1:8888' '5JhhMGNPsuU52XXjZ57FcDKvbb7KLrEhN65tdTQFrH51uruZLHi' 'eva' 'eva' 'communities'
+		"""
+		arguments = "'%s' '%s' '%s' '%s' '%s'" % (
+			self.http_address,
+			self.key_provider,
+			code,
+			scope,
+			table
+		)
+		response = muterun_js(self.current_dir + '/js/GetTable.js', arguments=arguments)
+		if response.exitcode == 0:
+			json_answer = response.stdout.decode('utf8')
+			json_value_ans = json.loads(json_answer)
+			return json_value_ans
+		else:
+		    raise GetTableException(response.stderr)
+		
 
 def load_data(stdout):
 	true_string = stdout.decode('utf8')
